@@ -29,6 +29,7 @@ use crate::test_utils::{
 };
 
 mod already_declared_attribute_codegen_tests;
+mod async_function_codegen_tests;
 mod conditional_compilation_codegen_tests;
 mod extern_rust_function_opaque_rust_type_argument_codegen_tests;
 mod extern_rust_function_opaque_rust_type_return_codegen_tests;
@@ -222,6 +223,7 @@ enum ExpectedSwiftCode {
 enum ExpectedCHeader {
     ExactAfterTrim(&'static str),
     ContainsAfterTrim(&'static str),
+    ContainsManyAfterTrim(Vec<&'static str>),
     DoesNotContainAfterTrim(&'static str),
     DoesNotContainManyAfterTrim(Vec<&'static str>),
     /// Skip testing C header
@@ -308,6 +310,11 @@ impl CodegenTest {
             ExpectedCHeader::ContainsAfterTrim(expected) => {
                 assert_trimmed_generated_contains_trimmed_expected(&c_header, expected);
             }
+            ExpectedCHeader::ContainsManyAfterTrim(many_expected) => {
+                for expected in many_expected {
+                    assert_trimmed_generated_contains_trimmed_expected(&c_header, expected);
+                }
+            }
             ExpectedCHeader::DoesNotContainAfterTrim(expected) => {
                 assert_trimmed_generated_does_not_contain_trimmed_expected(&c_header, expected);
             }
